--
-- UpdateMovingPartComponent
--
-- @author:    	Xentro (Marcus@Xentro.se)
-- @website:	www.Xentro.se
-- @history:	v1.0 - 2015-12-29 - Initial implementation
-- 

UpdateMovingPartComponent = {};

function UpdateMovingPartComponent.prerequisitesPresent(specializations)
    return true;
end;

function UpdateMovingPartComponent:load(xmlFile)
	self.movingIds = {};
	i = 0;
	while true do
		local key = string.format("vehicle.UpdateMovingPartComponent.part(%d)", i);
		if not hasXMLProperty(xmlFile, key) then break; end;
		
		local node = Utils.indexToObject(self.components, getXMLString(xmlFile, key .. "#node"));
		if node ~= nil then
			local toolId = getXMLInt(xmlFile, key .. "#movingToolIndice");
			
			if toolId ~= nil and self.movingTools[toolId + 1] ~= nil then
				table.insert(self.movingIds, {node = node, toolId = toolId + 1, lastUpdate = {0, 0, 0}});
			else
				print("UpdateMovingPartComponent - Error: Invalid movingToolIndice ( " .. tostring(toolId) .. " ) in " .. self.configFileName);
			end;
		end;
		
		i = i + 1;
	end;
end;

function UpdateMovingPartComponent:delete()
end;

function UpdateMovingPartComponent:readStream(streamId, connection)
end;

function UpdateMovingPartComponent:writeStream(streamId, connection)
end;

function UpdateMovingPartComponent:mouseEvent(posX, posY, isDown, isUp, button)
end;

function UpdateMovingPartComponent:keyEvent(unicode, sym, modifier, isDown)
end;

function UpdateMovingPartComponent:update(dt)
end;

function UpdateMovingPartComponent:updateTick(dt)
	if not self:getIsActive() then
		for _, v in ipairs(self.movingIds) do
			local newPosition = {getWorldTranslation(v.node)};
			local oldPosition = v.lastUpdate;
			local distance = Utils.vector3Length(newPosition[1] - oldPosition[1], newPosition[2] - oldPosition[2], newPosition[3] - oldPosition[3]);
			
			if distance > 0.001 then
				v.lastUpdate = newPosition;
				
				local tool = self.movingTools[v.toolId].node
				self:setMovingToolDirty(self.movingTools[v.toolId].node);
			end;
		end;
	end;
end;

function UpdateMovingPartComponent:draw()
end;